==> ocsp-client-6.0.0-sources.jar: org/xipki/ocsp/client/RequestOptions.java <==
/*
 *
 * Copyright (c) 2013 - 2020 Lijun Liao
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xipki.ocsp.client;

import org.xipki.security.HashAlgo;
import org.xipki.security.SignAlgo;

import java.util.Arrays;
import java.util.List;

import static org.xipki.util.Args.positive;

/**
 * OCSP request options.
 *
 * @author Lijun Liao
 * @since 2.0.0
 */

public class RequestOptions {

  private boolean signRequest;

  private boolean useNonce = true;

  private int nonceLen = 8;

  private boolean allowNoNonceInResponse;

  private boolean useHttpGetForRequest;

  private HashAlgo hashAlgorithm = HashAlgo.SHA256;

  private List<SignAlgo> preferredSignatureAlgorithms;

  public RequestOptions() {
  }

  public boolean isUseNonce() {
    return useNonce;
  }

  public void setUseNonce(boolean useNonce) {
    this.useNonce = useNonce;
  }

  public int getNonceLen() {
    return nonceLen;
  }

  public void setNonceLen(int nonceLen) {
    this.nonceLen = positive(nonceLen, "nonceLen");
  }

  public HashAlgo getHashAlgorithm() {
    return hashAlgorithm;
  }

  public void setHashAlgorithm(HashAlgo hashAlgorithm) {
    this.hashAlgorithm = hashAlgorithm;
  }

  public List<SignAlgo> getPreferredSignatureAlgorithms() {
    return preferredSignatureAlgorithms;
  }

  public void setPreferredSignatureAlgorithms(SignAlgo[] preferredSignatureAlgorithms) {
    this.preferredSignatureAlgorithms = Arrays.asList(preferredSignatureAlgorithms);
  }

  public boolean isUseHttpGetForRequest() {
    return useHttpGetForRequest;
  }

  public void setUseHttpGetForRequest(boolean useHttpGetForRequest) {
    this.useHttpGetForRequest = useHttpGetForRequest;
  }

  public boolean isSignRequest() {
    return signRequest;
  }

  public void setSignRequest(boolean signRequest) {
    this.signRequest = signRequest;
  }

  public boolean isAllowNoNonceInResponse() {
    return allowNoNonceInResponse;
  }

  public void setAllowNoNonceInResponse(boolean allowNoNonceInResponse) {
    this.allowNoNonceInResponse = allowNoNonceInResponse;
  }

}

==> ocsp-client-6.5.0-sources.jar: org/xipki/ocsp/client/RequestOptions.java <==
// Copyright (c) 2013-2023 xipki. All rights reserved.
// License Apache License 2.0

package org.xipki.ocsp.client;

import org.xipki.security.HashAlgo;
import org.xipki.security.SignAlgo;
import org.xipki.util.Args;

import java.util.Arrays;
import java.util.List;

/**
 * OCSP request options.
 *
 * @author Lijun Liao (xipki)
 * @since 2.0.0
 */

public class RequestOptions {

  private boolean signRequest;

  private boolean useNonce = true;

  private int nonceLen = 8;

  private boolean allowNoNonceInResponse;

  private boolean useHttpGetForRequest;

  private HashAlgo hashAlgorithm = HashAlgo.SHA256;

  private List<SignAlgo> preferredSignatureAlgorithms;

  public RequestOptions() {
  }

  public boolean isUseNonce() {
    return useNonce;
  }

  public void setUseNonce(boolean useNonce) {
    this.useNonce = useNonce;
  }

  public int getNonceLen() {
    return nonceLen;
  }

  public void setNonceLen(int nonceLen) {
    this.nonceLen = Args.positive(nonceLen, "nonceLen");
  }

  public HashAlgo getHashAlgorithm() {
    return hashAlgorithm;
  }

  public void setHashAlgorithm(HashAlgo hashAlgorithm) {
    this.hashAlgorithm = hashAlgorithm;
  }

  public List<SignAlgo> getPreferredSignatureAlgorithms() {
    return preferredSignatureAlgorithms;
  }

  public void setPreferredSignatureAlgorithms(SignAlgo[] preferredSignatureAlgorithms) {
    this.preferredSignatureAlgorithms = Arrays.asList(preferredSignatureAlgorithms);
  }

  public boolean isUseHttpGetForRequest() {
    return useHttpGetForRequest;
  }

  public void setUseHttpGetForRequest(boolean useHttpGetForRequest) {
    this.useHttpGetForRequest = useHttpGetForRequest;
  }

  public boolean isSignRequest() {
    return signRequest;
  }

  public void setSignRequest(boolean signRequest) {
    this.signRequest = signRequest;
  }

  public boolean isAllowNoNonceInResponse() {
    return allowNoNonceInResponse;
  }

  public void setAllowNoNonceInResponse(boolean allowNoNonceInResponse) {
    this.allowNoNonceInResponse = allowNoNonceInResponse;
  }

}
